==> beast-0.5.3.tar.gz: beast-0.5.3/bse/bsescripthelper.gen-proc.c <==

/**
 ** Generated data (by mkcproc.pl)
 **/
#line 1 "bsescripthelper.proc"

#include <bse/bseplugin.h>
#include <bse/bseprocedure.h>
#include <bse/bsecontainer.h>


#line 26 "bsescripthelper.proc"


/* --- bse-proxy-check --- */
static GType type_id_bse_proxy_check = 0;
static void
bse_proxy_check_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
#line 28 "bsescripthelper.proc"
 {
#line 30 "bsescripthelper.proc"
  *(in_pspecs++) = bse_param_spec_object ("item", "Item", "The Item",
				 BSE_TYPE_ITEM, SFI_PARAM_DEFAULT);
  *(in_pspecs++)    = sfi_pspec_string ("type_name", "Type Name", NULL,
			    NULL, SFI_PARAM_DEFAULT);
  *(out_pspecs++)   = sfi_pspec_bool ("is_a", NULL, NULL,
			  FALSE, SFI_PARAM_DEFAULT);
#line 24 "bsescripthelper.proc"
  proc->authors = "Tim Janik <timj@gtk.org>";
#line 25 "bsescripthelper.proc"
  proc->copyright = "Copyright (C) 2002 Tim Janik";
#line 36 "bsescripthelper.proc"
}  }
static BseErrorType
#line 36 "bsescripthelper.proc"
bse_proxy_check_exec (BseProcedureClass *proc,
	const GValue      *in_values,
	GValue            *out_values)
#line 39 "bsescripthelper.proc"
{
#line 40 "bsescripthelper.proc"
  
  BseItem *item    = bse_value_get_object (in_values++);
  gchar *type_name = sfi_value_get_string (in_values++);
  GType type;
  gboolean is_a;
  
#line 46 "bsescripthelper.proc"
  
  if (!type_name)
    type_name = "";
  
#line 50 "bsescripthelper.proc"
  
  type = g_type_from_name (type_name);
  is_a = item && g_type_is_a (G_OBJECT_TYPE (item), type);
  
#line 54 "bsescripthelper.proc"
  
  sfi_value_set_bool (out_values++, is_a);
  
  return BSE_ERROR_NONE;
}

/* --- Export to BSE --- */
BSE_EXPORTS_BEGIN (BSE_PLUGIN_NAME);
BSE_EXPORT_PROCEDURES = {
  { &type_id_bse_proxy_check, "bse-proxy-check", "Check whether a proxy has a certain type.", 0, bse_proxy_check_setup, bse_proxy_check_exec, NULL, "/Proc/Utils/Glue/Check", { 0, }, },
  { NULL, },
};
BSE_EXPORTS_END;

/**
 ** Generated data ends here
 **/

==> beast-0.5.5.tar.gz: beast-0.5.5/bse/bsescripthelper.gen-proc.c <==

/**
 ** Generated data (by mkcproc.pl)
 **/
#line 1 "bsescripthelper.proc"

#include <bse/bseplugin.h>
#include <bse/bseprocedure.h>
#include <bse/bsecontainer.h>


#line 26 "bsescripthelper.proc"


/* --- bse-proxy-check --- */
static void
bse_proxy_check_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
#line 28 "bsescripthelper.proc"
 {
#line 30 "bsescripthelper.proc"
  *(in_pspecs++) = bse_param_spec_object ("item", "Item", "The Item",
				 BSE_TYPE_ITEM, SFI_PARAM_DEFAULT);
  *(in_pspecs++)    = sfi_pspec_string ("type_name", "Type Name", NULL,
			    NULL, SFI_PARAM_DEFAULT);
  *(out_pspecs++)   = sfi_pspec_bool ("is_a", NULL, NULL,
			  FALSE, SFI_PARAM_DEFAULT);
#line 24 "bsescripthelper.proc"
  proc->authors = "Tim Janik <timj@gtk.org>";
#line 25 "bsescripthelper.proc"
  proc->license = "GNU Lesser General Public License";
#line 36 "bsescripthelper.proc"
}  }
static BseErrorType
#line 36 "bsescripthelper.proc"
bse_proxy_check_exec (BseProcedureClass *proc,
	const GValue      *in_values,
	GValue            *out_values)
#line 39 "bsescripthelper.proc"
{
#line 40 "bsescripthelper.proc"
  
  BseItem *item    = bse_value_get_object (in_values++);
  gchar *type_name = sfi_value_get_string (in_values++);
  GType type;
  gboolean is_a;
  
#line 46 "bsescripthelper.proc"
  
  if (!type_name)
    type_name = "";
  
#line 50 "bsescripthelper.proc"
  
  type = g_type_from_name (type_name);
  is_a = item && g_type_is_a (G_OBJECT_TYPE (item), type);
  
#line 54 "bsescripthelper.proc"
  
  sfi_value_set_bool (out_values++, is_a);
  
  return BSE_ERROR_NONE;
}

/* --- Export to BSE --- */
static BseExportNodeProc __enode_bse_proxy_check = {
  { NULL, BSE_EXPORT_NODE_PROC,
    "bse-proxy-check", "/Proc/Proxy Check", "Check whether a proxy has a certain type." },
  0, bse_proxy_check_setup, bse_proxy_check_exec, 
};
BseExportNode* bse__builtin_init_bsescripthelper_gen_proc_c (void);
BseExportNode* bse__builtin_init_bsescripthelper_gen_proc_c (void)
{
  return (BseExportNode*) &__enode_bse_proxy_check;
}

/**
 ** Generated data ends here
 **/
